# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/nn/module.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2
from gRPC_impl.mytorch.nn import nn_msg_types_pb2 as mytorch_dot_nn_dot_nn__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17mytorch/nn/module.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\x1a\x1dmytorch/nn/nn_msg_types.proto\"5\n\x15ModuleToDeviceRequest\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\t\"$\n\nParameters\x12\x16\n\x0egenerator_uuid\x18\x01 \x01(\t\"\x1c\n\x0chalf_request\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"-\n\rhalf_response\x12\x1c\n\x05\x65mpty\x18\x01 \x01(\x0b\x32\r.shared.Empty2\xe5\x03\n\rModuleService\x12:\n\x07\x46orward\x12\x1b.mytorch.ForwardPassRequest\x1a\x12.shared.GrpcTensor\x12\x33\n\x14\x43reateModuleOnServer\x12\r.shared.Empty\x1a\x0c.shared.UUID\x12\x33\n\x0cGetStateDict\x12\x0c.shared.UUID\x1a\x13.shared.NamedTensor0\x01\x12<\n\rLoadStateDict\x12\x13.shared.NamedTensor\x1a\x14.shared.BooleanValue(\x01\x12#\n\x04\x45val\x12\x0c.shared.UUID\x1a\r.shared.Empty\x12\x39\n\x08ToDevice\x12\x1e.mytorch.ModuleToDeviceRequest\x1a\r.shared.Empty\x12\x32\n\rGetParameters\x12\x0c.shared.UUID\x1a\x13.mytorch.Parameters\x12\x35\n\x04half\x12\x15.mytorch.half_request\x1a\x16.mytorch.half_response\x12%\n\x06\x64\x65lete\x12\x0c.shared.UUID\x1a\r.shared.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.nn.module_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODULETODEVICEREQUEST']._serialized_start=91
  _globals['_MODULETODEVICEREQUEST']._serialized_end=144
  _globals['_PARAMETERS']._serialized_start=146
  _globals['_PARAMETERS']._serialized_end=182
  _globals['_HALF_REQUEST']._serialized_start=184
  _globals['_HALF_REQUEST']._serialized_end=212
  _globals['_HALF_RESPONSE']._serialized_start=214
  _globals['_HALF_RESPONSE']._serialized_end=259
  _globals['_MODULESERVICE']._serialized_start=262
  _globals['_MODULESERVICE']._serialized_end=747
# @@protoc_insertion_point(module_scope)
