# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from gRPC_impl.mytorch.scaffolding import data_mgmt_pb2 as mytorch_dot_scaffolding_dot_data__mgmt__pb2
from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2

GRPC_GENERATED_VERSION = '1.65.0'
GRPC_VERSION = grpc.__version__
EXPECTED_ERROR_RELEASE = '1.65.0'
SCHEDULED_RELEASE_DATE = 'June 25, 2024'
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    warnings.warn(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in mytorch/scaffolding/data_mgmt_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
        + f' This warning will become an error in {EXPECTED_ERROR_RELEASE},'
        + f' scheduled for release on {SCHEDULED_RELEASE_DATE}.',
        RuntimeWarning
    )


class DataMgmtServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.UploadFolder = channel.stream_unary(
                '/mytorch.DataMgmtService/UploadFolder',
                request_serializer=mytorch_dot_scaffolding_dot_data__mgmt__pb2.FileUploadRequest.SerializeToString,
                response_deserializer=mytorch_dot_scaffolding_dot_data__mgmt__pb2.FolderUploadResponse.FromString,
                _registered_method=True)
        self.FolderExistsOnServer = channel.unary_unary(
                '/mytorch.DataMgmtService/FolderExistsOnServer',
                request_serializer=mytorch_dot_scaffolding_dot_data__mgmt__pb2.RelativePath.SerializeToString,
                response_deserializer=shared__msg__types__pb2.BooleanValue.FromString,
                _registered_method=True)
        self.SetServerDataDir = channel.unary_unary(
                '/mytorch.DataMgmtService/SetServerDataDir',
                request_serializer=mytorch_dot_scaffolding_dot_data__mgmt__pb2.DataDir.SerializeToString,
                response_deserializer=shared__msg__types__pb2.Empty.FromString,
                _registered_method=True)


class DataMgmtServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def UploadFolder(self, request_iterator, context):
        """The client will create a single streaming RPC call for the session and send
        multiple FileUploadRequest messages—one for each file in the directory
        (including nested directories if needed).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def FolderExistsOnServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetServerDataDir(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataMgmtServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'UploadFolder': grpc.stream_unary_rpc_method_handler(
                    servicer.UploadFolder,
                    request_deserializer=mytorch_dot_scaffolding_dot_data__mgmt__pb2.FileUploadRequest.FromString,
                    response_serializer=mytorch_dot_scaffolding_dot_data__mgmt__pb2.FolderUploadResponse.SerializeToString,
            ),
            'FolderExistsOnServer': grpc.unary_unary_rpc_method_handler(
                    servicer.FolderExistsOnServer,
                    request_deserializer=mytorch_dot_scaffolding_dot_data__mgmt__pb2.RelativePath.FromString,
                    response_serializer=shared__msg__types__pb2.BooleanValue.SerializeToString,
            ),
            'SetServerDataDir': grpc.unary_unary_rpc_method_handler(
                    servicer.SetServerDataDir,
                    request_deserializer=mytorch_dot_scaffolding_dot_data__mgmt__pb2.DataDir.FromString,
                    response_serializer=shared__msg__types__pb2.Empty.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'mytorch.DataMgmtService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('mytorch.DataMgmtService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DataMgmtService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def UploadFolder(request_iterator,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.stream_unary(
            request_iterator,
            target,
            '/mytorch.DataMgmtService/UploadFolder',
            mytorch_dot_scaffolding_dot_data__mgmt__pb2.FileUploadRequest.SerializeToString,
            mytorch_dot_scaffolding_dot_data__mgmt__pb2.FolderUploadResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def FolderExistsOnServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/mytorch.DataMgmtService/FolderExistsOnServer',
            mytorch_dot_scaffolding_dot_data__mgmt__pb2.RelativePath.SerializeToString,
            shared__msg__types__pb2.BooleanValue.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def SetServerDataDir(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/mytorch.DataMgmtService/SetServerDataDir',
            mytorch_dot_scaffolding_dot_data__mgmt__pb2.DataDir.SerializeToString,
            shared__msg__types__pb2.Empty.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
