# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: shared_msg_types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16shared_msg_types.proto\x12\x06shared\"3\n\x16SerializedTensorObject\x12\x19\n\x11serialized_tensor\x18\x02 \x01(\x0c\"B\n\x14SerializedNumpyArray\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05shape\x18\x02 \x03(\x05\x12\r\n\x05\x64type\x18\x03 \x01(\t\"B\n\x14SerializedTensorData\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\r\n\x05shape\x18\x02 \x03(\x05\x12\r\n\x05\x64type\x18\x03 \x01(\t\"\x1d\n\x0cIntegerValue\x12\r\n\x05value\x18\x01 \x01(\x05\"\x1b\n\nFloatValue\x12\r\n\x05value\x18\x01 \x01(\x02\"\x1c\n\x0bStringValue\x12\r\n\x05value\x18\x01 \x01(\t\"(\n\nStringPair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"4\n\x0eReshapeRequest\x12\x13\n\x0btensor_uuid\x18\x01 \x01(\t\x12\r\n\x05shape\x18\x02 \x03(\x05\"\x07\n\x05\x45mpty\"\x1d\n\x0c\x42ooleanValue\x12\r\n\x05value\x18\x01 \x01(\x08\"t\n\x10StringDictionary\x12\x32\n\x05items\x18\x01 \x03(\x0b\x32#.shared.StringDictionary.ItemsEntry\x1a,\n\nItemsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"~\n\x0ckeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x16\n\x0cstring_value\x18\x02 \x01(\tH\x00\x12\x13\n\tint_value\x18\x03 \x01(\x05H\x00\x12\x15\n\x0b\x66loat_value\x18\x04 \x01(\x02H\x00\x12\x14\n\nbool_value\x18\x05 \x01(\x08H\x00\x42\x07\n\x05value\"\x14\n\x04UUID\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"\x16\n\x05\x44type\x12\r\n\x05\x64type\x18\x01 \x01(\t\"2\n\x0eTensorIDAndDim\x12\x13\n\x0btensor_uuid\x18\x01 \x01(\t\x12\x0b\n\x03\x64im\x18\x02 \x01(\x05\"4\n\x0fTensorIDsAndDim\x12\x14\n\x0ctensor_uuids\x18\x01 \x03(\t\x12\x0b\n\x03\x64im\x18\x02 \x01(\x05\":\n\x0cTwoTensorIDs\x12\x14\n\x0ctensor1_uuid\x18\x01 \x01(\t\x12\x14\n\x0ctensor2_uuid\x18\x02 \x01(\t\"\x1c\n\x0bTensorShape\x12\r\n\x05shape\x18\x01 \x03(\x05\"8\n\nGrpcTensor\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\r\n\x05shape\x18\x02 \x03(\x05\x12\r\n\x05\x64type\x18\x03 \x01(\t\"?\n\x0bNamedTensor\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\"\n\x06tensor\x18\x02 \x01(\x0b\x32\x12.shared.GrpcTensor\"Z\n\x0eTwoGrpcTensors\x12#\n\x07tensor1\x18\x01 \x01(\x0b\x32\x12.shared.GrpcTensor\x12#\n\x07tensor2\x18\x02 \x01(\x0b\x32\x12.shared.GrpcTensor\":\n\x13MultipleGrpcTensors\x12#\n\x07tensors\x18\x01 \x03(\x0b\x32\x12.shared.GrpcTensor\"i\n\x05Value\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x42\x06\n\x04kind\"]\n\tFileChunk\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x12\n\nchunk_data\x18\x02 \x01(\x0c\x12\x13\n\x0b\x63hunk_index\x18\x03 \x01(\x05\x12\x15\n\ris_last_chunk\x18\x04 \x01(\x08\"#\n\x0bJsonRequest\x12\x14\n\x0cjson_payload\x18\x01 \x01(\t\"$\n\x0cJsonResponse\x12\x14\n\x0cjson_payload\x18\x01 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'shared_msg_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_STRINGDICTIONARY_ITEMSENTRY']._loaded_options = None
  _globals['_STRINGDICTIONARY_ITEMSENTRY']._serialized_options = b'8\001'
  _globals['_SERIALIZEDTENSOROBJECT']._serialized_start=34
  _globals['_SERIALIZEDTENSOROBJECT']._serialized_end=85
  _globals['_SERIALIZEDNUMPYARRAY']._serialized_start=87
  _globals['_SERIALIZEDNUMPYARRAY']._serialized_end=153
  _globals['_SERIALIZEDTENSORDATA']._serialized_start=155
  _globals['_SERIALIZEDTENSORDATA']._serialized_end=221
  _globals['_INTEGERVALUE']._serialized_start=223
  _globals['_INTEGERVALUE']._serialized_end=252
  _globals['_FLOATVALUE']._serialized_start=254
  _globals['_FLOATVALUE']._serialized_end=281
  _globals['_STRINGVALUE']._serialized_start=283
  _globals['_STRINGVALUE']._serialized_end=311
  _globals['_STRINGPAIR']._serialized_start=313
  _globals['_STRINGPAIR']._serialized_end=353
  _globals['_RESHAPEREQUEST']._serialized_start=355
  _globals['_RESHAPEREQUEST']._serialized_end=407
  _globals['_EMPTY']._serialized_start=409
  _globals['_EMPTY']._serialized_end=416
  _globals['_BOOLEANVALUE']._serialized_start=418
  _globals['_BOOLEANVALUE']._serialized_end=447
  _globals['_STRINGDICTIONARY']._serialized_start=449
  _globals['_STRINGDICTIONARY']._serialized_end=565
  _globals['_STRINGDICTIONARY_ITEMSENTRY']._serialized_start=521
  _globals['_STRINGDICTIONARY_ITEMSENTRY']._serialized_end=565
  _globals['_KEYVALUEPAIR']._serialized_start=567
  _globals['_KEYVALUEPAIR']._serialized_end=693
  _globals['_UUID']._serialized_start=695
  _globals['_UUID']._serialized_end=715
  _globals['_DTYPE']._serialized_start=717
  _globals['_DTYPE']._serialized_end=739
  _globals['_TENSORIDANDDIM']._serialized_start=741
  _globals['_TENSORIDANDDIM']._serialized_end=791
  _globals['_TENSORIDSANDDIM']._serialized_start=793
  _globals['_TENSORIDSANDDIM']._serialized_end=845
  _globals['_TWOTENSORIDS']._serialized_start=847
  _globals['_TWOTENSORIDS']._serialized_end=905
  _globals['_TENSORSHAPE']._serialized_start=907
  _globals['_TENSORSHAPE']._serialized_end=935
  _globals['_GRPCTENSOR']._serialized_start=937
  _globals['_GRPCTENSOR']._serialized_end=993
  _globals['_NAMEDTENSOR']._serialized_start=995
  _globals['_NAMEDTENSOR']._serialized_end=1058
  _globals['_TWOGRPCTENSORS']._serialized_start=1060
  _globals['_TWOGRPCTENSORS']._serialized_end=1150
  _globals['_MULTIPLEGRPCTENSORS']._serialized_start=1152
  _globals['_MULTIPLEGRPCTENSORS']._serialized_end=1210
  _globals['_VALUE']._serialized_start=1212
  _globals['_VALUE']._serialized_end=1317
  _globals['_FILECHUNK']._serialized_start=1319
  _globals['_FILECHUNK']._serialized_end=1412
  _globals['_JSONREQUEST']._serialized_start=1414
  _globals['_JSONREQUEST']._serialized_end=1449
  _globals['_JSONRESPONSE']._serialized_start=1451
  _globals['_JSONRESPONSE']._serialized_end=1487
# @@protoc_insertion_point(module_scope)
