# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/scaffolding/data_mgmt.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#mytorch/scaffolding/data_mgmt.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\"6\n\x11\x46ileUploadRequest\x12\x10\n\x08\x66ilepath\x18\x01 \x01(\t\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\x0c\"%\n\x14\x46olderUploadResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\x05\"\x1c\n\x0cRelativePath\x12\x0c\n\x04path\x18\x01 \x01(\t\"\x17\n\x07\x44\x61taDir\x12\x0c\n\x04path\x18\x01 \x01(\t2\xd8\x01\n\x0f\x44\x61taMgmtService\x12K\n\x0cUploadFolder\x12\x1a.mytorch.FileUploadRequest\x1a\x1d.mytorch.FolderUploadResponse(\x01\x12\x43\n\x14\x46olderExistsOnServer\x12\x15.mytorch.RelativePath\x1a\x14.shared.BooleanValue\x12\x33\n\x10SetServerDataDir\x12\x10.mytorch.DataDir\x1a\r.shared.Emptyb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.scaffolding.data_mgmt_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FILEUPLOADREQUEST']._serialized_start=72
  _globals['_FILEUPLOADREQUEST']._serialized_end=126
  _globals['_FOLDERUPLOADRESPONSE']._serialized_start=128
  _globals['_FOLDERUPLOADRESPONSE']._serialized_end=165
  _globals['_RELATIVEPATH']._serialized_start=167
  _globals['_RELATIVEPATH']._serialized_end=195
  _globals['_DATADIR']._serialized_start=197
  _globals['_DATADIR']._serialized_end=220
  _globals['_DATAMGMTSERVICE']._serialized_start=223
  _globals['_DATAMGMTSERVICE']._serialized_end=439
# @@protoc_insertion_point(module_scope)
