# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/nn/loss_functions.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmytorch/nn/loss_functions.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\"L\n\x13LossFunctionRequest\x12\x35\n\x12loss_function_type\x18\x01 \x01(\x0e\x32\x19.mytorch.LossFunctionType\"]\n\x16RunLossFunctionRequest\x12\x1a\n\x12loss_function_uuid\x18\x01 \x01(\t\x12\x12\n\ninput_uuid\x18\x02 \x01(\t\x12\x13\n\x0btarget_uuid\x18\x03 \x01(\t*\x87\x02\n\x10LossFunctionType\x12\x07\n\x03MSE\x10\x00\x12\x06\n\x02L1\x10\x01\x12\x10\n\x0c\x43rossEntropy\x10\x02\x12\x07\n\x03NLL\x10\x03\x12\x0e\n\nPoissonNLL\x10\x04\x12\t\n\x05KLDiv\x10\x05\x12\x07\n\x03\x42\x43\x45\x10\x06\x12\x11\n\rMarginRanking\x10\x07\x12\t\n\x05Hinge\x10\x08\x12\x14\n\x10MultiLabelMargin\x10\t\x12\x0c\n\x08SmoothL1\x10\n\x12\x0e\n\nSoftMargin\x10\x0b\x12\x18\n\x14MultiLabelSoftMargin\x10\x0c\x12\x13\n\x0f\x43osineEmbedding\x10\r\x12\x0f\n\x0bMultiMargin\x10\x0e\x12\x11\n\rTripletMargin\x10\x0f\x32\x9f\x01\n\x13LossFunctionService\x12@\n\x12\x43reateLossFunction\x12\x1c.mytorch.LossFunctionRequest\x1a\x0c.shared.UUID\x12\x46\n\x0fRunLossFunction\x12\x1f.mytorch.RunLossFunctionRequest\x1a\x12.shared.GrpcTensorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.nn.loss_functions_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LOSSFUNCTIONTYPE']._serialized_start=242
  _globals['_LOSSFUNCTIONTYPE']._serialized_end=505
  _globals['_LOSSFUNCTIONREQUEST']._serialized_start=68
  _globals['_LOSSFUNCTIONREQUEST']._serialized_end=144
  _globals['_RUNLOSSFUNCTIONREQUEST']._serialized_start=146
  _globals['_RUNLOSSFUNCTIONREQUEST']._serialized_end=239
  _globals['_LOSSFUNCTIONSERVICE']._serialized_start=508
  _globals['_LOSSFUNCTIONSERVICE']._serialized_end=667
# @@protoc_insertion_point(module_scope)
