# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/nn/nn_msg_types.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dmytorch/nn/nn_msg_types.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\"\x9f\x01\n\x13SerializedStateDict\x12:\n\x07\x65ntries\x18\x01 \x03(\x0b\x32).mytorch.SerializedStateDict.EntriesEntry\x1aL\n\x0c\x45ntriesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.shared.SerializedTensorData:\x02\x38\x01\"\'\n\x07NNLayer\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x0e\n\x06params\x18\x02 \x03(\t\",\n\x08NNLayers\x12 \n\x06layers\x18\x01 \x03(\x0b\x32\x10.mytorch.NNLayer\">\n\x12\x46orwardPassRequest\x12\x13\n\x0bmodule_uuid\x18\x01 \x01(\t\x12\x13\n\x0btensor_uuid\x18\x02 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.nn.nn_msg_types_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SERIALIZEDSTATEDICT_ENTRIESENTRY']._loaded_options = None
  _globals['_SERIALIZEDSTATEDICT_ENTRIESENTRY']._serialized_options = b'8\001'
  _globals['_SERIALIZEDSTATEDICT']._serialized_start=67
  _globals['_SERIALIZEDSTATEDICT']._serialized_end=226
  _globals['_SERIALIZEDSTATEDICT_ENTRIESENTRY']._serialized_start=150
  _globals['_SERIALIZEDSTATEDICT_ENTRIESENTRY']._serialized_end=226
  _globals['_NNLAYER']._serialized_start=228
  _globals['_NNLAYER']._serialized_end=267
  _globals['_NNLAYERS']._serialized_start=269
  _globals['_NNLAYERS']._serialized_end=313
  _globals['_FORWARDPASSREQUEST']._serialized_start=315
  _globals['_FORWARDPASSREQUEST']._serialized_end=377
# @@protoc_insertion_point(module_scope)
