# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/nn/functional/functional.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&mytorch/nn/functional/functional.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\"2\n\x0eSoftmaxRequest\x12\x13\n\x0btensor_uuid\x18\x01 \x01(\t\x12\x0b\n\x03\x64im\x18\x02 \x01(\x05\x32K\n\x11\x46unctionalService\x12\x36\n\x07softmax\x12\x17.mytorch.SoftmaxRequest\x1a\x12.shared.GrpcTensorb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.nn.functional.functional_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SOFTMAXREQUEST']._serialized_start=75
  _globals['_SOFTMAXREQUEST']._serialized_end=125
  _globals['_FUNCTIONALSERVICE']._serialized_start=127
  _globals['_FUNCTIONALSERVICE']._serialized_end=202
# @@protoc_insertion_point(module_scope)
