# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/nn/sequential.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2
from gRPC_impl.mytorch.nn import nn_msg_types_pb2 as mytorch_dot_nn_dot_nn__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bmytorch/nn/sequential.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\x1a\x1dmytorch/nn/nn_msg_types.proto2V\n\x11SequentialService\x12\x41\n\x1e\x43reateSequentialModuleOnServer\x12\x11.mytorch.NNLayers\x1a\x0c.shared.UUIDb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.nn.sequential_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SEQUENTIALSERVICE']._serialized_start=95
  _globals['_SEQUENTIALSERVICE']._serialized_end=181
# @@protoc_insertion_point(module_scope)
