# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/tensor.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14mytorch/tensor.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\"\x93\x02\n\x16TensorStreamingRequest\x12\x0e\n\x06method\x18\x01 \x01(\t\x12\x1c\n\x04uuid\x18\x02 \x01(\x0b\x32\x0c.shared.UUIDH\x00\x12+\n\x0btwo_tensors\x18\x03 \x01(\x0b\x32\x14.shared.TwoTensorIDsH\x00\x12\x30\n\x0etensor_and_dim\x18\x04 \x01(\x0b\x32\x16.shared.TensorIDAndDimH\x00\x12\x31\n\x0freshape_request\x18\x05 \x01(\x0b\x32\x16.shared.ReshapeRequestH\x00\x12.\n\rslice_request\x18\x06 \x01(\x0b\x32\x15.mytorch.SliceRequestH\x00\x42\t\n\x07payload\"\xc9\x01\n\x17TensorStreamingResponse\x12$\n\x06tensor\x18\x01 \x01(\x0b\x32\x12.shared.GrpcTensorH\x00\x12)\n\x0b\x66loat_value\x18\x02 \x01(\x0b\x32\x12.shared.FloatValueH\x00\x12+\n\x0ctensor_shape\x18\x03 \x01(\x0b\x32\x13.shared.TensorShapeH\x00\x12%\n\x0ctensor_dtype\x18\x04 \x01(\x0b\x32\r.shared.DtypeH\x00\x42\t\n\x07payload\"8\n\x0bTensorSlice\x12\r\n\x05start\x18\x01 \x01(\x05\x12\x0c\n\x04stop\x18\x02 \x01(\x05\x12\x0c\n\x04step\x18\x03 \x01(\x05\"I\n\x0cSliceRequest\x12\x13\n\x0btensor_uuid\x18\x01 \x01(\t\x12$\n\x06slices\x18\x02 \x03(\x0b\x32\x14.mytorch.TensorSlice2\xcb\x07\n\rTensorService\x12)\n\x05\x66loat\x12\x0c.shared.UUID\x1a\x12.shared.GrpcTensor\x12(\n\x04long\x12\x0c.shared.UUID\x1a\x12.shared.GrpcTensor\x12,\n\x08\x62\x61\x63kward\x12\x0c.shared.UUID\x1a\x12.shared.GrpcTensor\x12+\n\x07to_cuda\x12\x0c.shared.UUID\x1a\x12.shared.GrpcTensor\x12*\n\x06to_cpu\x12\x0c.shared.UUID\x1a\x12.shared.GrpcTensor\x12\'\n\x03sum\x12\x0c.shared.UUID\x1a\x12.shared.GrpcTensor\x12/\n\x03\x61\x64\x64\x12\x14.shared.TwoTensorIDs\x1a\x12.shared.GrpcTensor\x12\x31\n\x05\x65qual\x12\x14.shared.TwoTensorIDs\x1a\x12.shared.GrpcTensor\x12\x33\n\x05index\x12\x16.shared.TensorIDAndDim\x1a\x12.shared.GrpcTensor\x12\x37\n\tunsqueeze\x12\x16.shared.TensorIDAndDim\x1a\x12.shared.GrpcTensor\x12\x35\n\x07reshape\x12\x16.shared.ReshapeRequest\x1a\x12.shared.GrpcTensor\x12\x32\n\x05slice\x12\x15.mytorch.SliceRequest\x1a\x12.shared.GrpcTensor\x12\x36\n\x08get_data\x12\x0c.shared.UUID\x1a\x1c.shared.SerializedTensorData\x12(\n\x04item\x12\x0c.shared.UUID\x1a\x12.shared.FloatValue\x12.\n\tget_shape\x12\x0c.shared.UUID\x1a\x13.shared.TensorShape\x12(\n\tget_dtype\x12\x0c.shared.UUID\x1a\r.shared.Dtype\x12%\n\x06\x64\x65lete\x12\x0c.shared.UUID\x1a\r.shared.Empty\x12Z\n\x11TensorStreamingOp\x12\x1f.mytorch.TensorStreamingRequest\x1a .mytorch.TensorStreamingResponse(\x01\x30\x01\x12\x39\n\x0cgeneric_call\x12\x13.shared.JsonRequest\x1a\x14.shared.JsonResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.tensor_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TENSORSTREAMINGREQUEST']._serialized_start=58
  _globals['_TENSORSTREAMINGREQUEST']._serialized_end=333
  _globals['_TENSORSTREAMINGRESPONSE']._serialized_start=336
  _globals['_TENSORSTREAMINGRESPONSE']._serialized_end=537
  _globals['_TENSORSLICE']._serialized_start=539
  _globals['_TENSORSLICE']._serialized_end=595
  _globals['_SLICEREQUEST']._serialized_start=597
  _globals['_SLICEREQUEST']._serialized_end=670
  _globals['_TENSORSERVICE']._serialized_start=673
  _globals['_TENSORSERVICE']._serialized_end=1644
# @@protoc_insertion_point(module_scope)
