# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/hub/hub.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15mytorch/hub/hub.proto\x12\x07mytorch\"J\n\x10ModelLoadRequest\x12\x0c\n\x04repo\x18\x01 \x01(\t\x12\x12\n\nmodel_name\x18\x02 \x01(\t\x12\x14\n\x0cweights_enum\x18\x03 \x01(\t\"\'\n\x11ModelLoadResponse\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t2P\n\nHubService\x12\x42\n\tloadModel\x12\x19.mytorch.ModelLoadRequest\x1a\x1a.mytorch.ModelLoadResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.hub.hub_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODELLOADREQUEST']._serialized_start=34
  _globals['_MODELLOADREQUEST']._serialized_end=108
  _globals['_MODELLOADRESPONSE']._serialized_start=110
  _globals['_MODELLOADRESPONSE']._serialized_end=149
  _globals['_HUBSERVICE']._serialized_start=151
  _globals['_HUBSERVICE']._serialized_end=231
# @@protoc_insertion_point(module_scope)
