# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/scaffolding/server_mgmt.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n mytorch/scaffolding/server_mgmt.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\"b\n\x0cServerStatus\x12\x13\n\x0bserver_name\x18\x01 \x01(\t\x12\x11\n\tserver_ip\x18\x02 \x01(\t\x12\x13\n\x0bserver_port\x18\x03 \x01(\x05\x12\x15\n\rserver_status\x18\x04 \x01(\t\":\n\x0bGpuInfoList\x12+\n\tgpu_dicts\x18\x01 \x03(\x0b\x32\x18.shared.StringDictionary2\xbc\x01\n\x11ServerMgmtService\x12\x35\n\rserver_status\x12\r.shared.Empty\x1a\x15.mytorch.ServerStatus\x12\x33\n\x11\x63lient_disconnect\x12\r.shared.Empty\x1a\r.shared.Empty\"\x00\x12;\n\x14get_server_gpu_stats\x12\r.shared.Empty\x1a\x14.mytorch.GpuInfoListb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.scaffolding.server_mgmt_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SERVERSTATUS']._serialized_start=69
  _globals['_SERVERSTATUS']._serialized_end=167
  _globals['_GPUINFOLIST']._serialized_start=169
  _globals['_GPUINFOLIST']._serialized_end=227
  _globals['_SERVERMGMTSERVICE']._serialized_start=230
  _globals['_SERVERMGMTSERVICE']._serialized_end=418
# @@protoc_insertion_point(module_scope)
