# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from gRPC_impl.mytorch.utils.data import data_pb2 as mytorch_dot_utils_dot_data_dot_data__pb2

GRPC_GENERATED_VERSION = '1.71.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + f' but the generated code in mytorch/utils/data/data_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class DataServiceStub(object):
    """/////////////////////////////////////////////////////////////////////////////////
    Service definition
    /////////////////////////////////////////////////////////////////////////////////
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateSubsetOnServer = channel.unary_unary(
                '/mytorch.DataService/CreateSubsetOnServer',
                request_serializer=mytorch_dot_utils_dot_data_dot_data__pb2.CreateSubsetRequest.SerializeToString,
                response_deserializer=mytorch_dot_utils_dot_data_dot_data__pb2.GrpcSubset.FromString,
                _registered_method=True)
        self.CreateDataLoaderOnServer = channel.unary_unary(
                '/mytorch.DataService/CreateDataLoaderOnServer',
                request_serializer=mytorch_dot_utils_dot_data_dot_data__pb2.CreateDataLoaderRequest.SerializeToString,
                response_deserializer=mytorch_dot_utils_dot_data_dot_data__pb2.GrpcDataLoader.FromString,
                _registered_method=True)
        self.GetNextDataLoaderBatch = channel.unary_unary(
                '/mytorch.DataService/GetNextDataLoaderBatch',
                request_serializer=mytorch_dot_utils_dot_data_dot_data__pb2.GetNextBatchRequest.SerializeToString,
                response_deserializer=mytorch_dot_utils_dot_data_dot_data__pb2.DataLoaderBatchResponse.FromString,
                _registered_method=True)


class DataServiceServicer(object):
    """/////////////////////////////////////////////////////////////////////////////////
    Service definition
    /////////////////////////////////////////////////////////////////////////////////
    """

    def CreateSubsetOnServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateDataLoaderOnServer(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNextDataLoaderBatch(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_DataServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateSubsetOnServer': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateSubsetOnServer,
                    request_deserializer=mytorch_dot_utils_dot_data_dot_data__pb2.CreateSubsetRequest.FromString,
                    response_serializer=mytorch_dot_utils_dot_data_dot_data__pb2.GrpcSubset.SerializeToString,
            ),
            'CreateDataLoaderOnServer': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateDataLoaderOnServer,
                    request_deserializer=mytorch_dot_utils_dot_data_dot_data__pb2.CreateDataLoaderRequest.FromString,
                    response_serializer=mytorch_dot_utils_dot_data_dot_data__pb2.GrpcDataLoader.SerializeToString,
            ),
            'GetNextDataLoaderBatch': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNextDataLoaderBatch,
                    request_deserializer=mytorch_dot_utils_dot_data_dot_data__pb2.GetNextBatchRequest.FromString,
                    response_serializer=mytorch_dot_utils_dot_data_dot_data__pb2.DataLoaderBatchResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'mytorch.DataService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('mytorch.DataService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class DataService(object):
    """/////////////////////////////////////////////////////////////////////////////////
    Service definition
    /////////////////////////////////////////////////////////////////////////////////
    """

    @staticmethod
    def CreateSubsetOnServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/mytorch.DataService/CreateSubsetOnServer',
            mytorch_dot_utils_dot_data_dot_data__pb2.CreateSubsetRequest.SerializeToString,
            mytorch_dot_utils_dot_data_dot_data__pb2.GrpcSubset.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def CreateDataLoaderOnServer(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/mytorch.DataService/CreateDataLoaderOnServer',
            mytorch_dot_utils_dot_data_dot_data__pb2.CreateDataLoaderRequest.SerializeToString,
            mytorch_dot_utils_dot_data_dot_data__pb2.GrpcDataLoader.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetNextDataLoaderBatch(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/mytorch.DataService/GetNextDataLoaderBatch',
            mytorch_dot_utils_dot_data_dot_data__pb2.GetNextBatchRequest.SerializeToString,
            mytorch_dot_utils_dot_data_dot_data__pb2.DataLoaderBatchResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
