# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/resnet/resnet.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bmytorch/resnet/resnet.proto\x12\x07mytorch\"u\n\x1a\x43reateResidualBlockRequest\x12\x13\n\x0bin_channels\x18\x01 \x01(\x05\x12\x14\n\x0cout_channels\x18\x02 \x01(\x05\x12\x0e\n\x06stride\x18\x03 \x01(\x05\x12\x1c\n\x14\x64ownample_model_uuid\x18\x04 \x01(\t\"1\n\x1b\x43reateResidualBlockResponse\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\"?\n\x18\x43reateResNetModelRequest\x12\x13\n\x0bnum_classes\x18\x01 \x01(\x05\x12\x0e\n\x06layers\x18\x02 \x03(\x05\"/\n\x19\x43reateResNetModelResponse\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t2\xcd\x01\n\rResnetService\x12`\n\x13\x43reateResidualBlock\x12#.mytorch.CreateResidualBlockRequest\x1a$.mytorch.CreateResidualBlockResponse\x12Z\n\x11\x43reateResNetModel\x12!.mytorch.CreateResNetModelRequest\x1a\".mytorch.CreateResNetModelResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.resnet.resnet_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_CREATERESIDUALBLOCKREQUEST']._serialized_start=40
  _globals['_CREATERESIDUALBLOCKREQUEST']._serialized_end=157
  _globals['_CREATERESIDUALBLOCKRESPONSE']._serialized_start=159
  _globals['_CREATERESIDUALBLOCKRESPONSE']._serialized_end=208
  _globals['_CREATERESNETMODELREQUEST']._serialized_start=210
  _globals['_CREATERESNETMODELREQUEST']._serialized_end=273
  _globals['_CREATERESNETMODELRESPONSE']._serialized_start=275
  _globals['_CREATERESNETMODELRESPONSE']._serialized_end=322
  _globals['_RESNETSERVICE']._serialized_start=325
  _globals['_RESNETSERVICE']._serialized_end=530
# @@protoc_insertion_point(module_scope)
