# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/cuda/cuda.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17mytorch/cuda/cuda.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\"\x16\n\x14is_available_request\"-\n\x15is_available_response\x12\x14\n\x0cis_available\x18\x01 \x01(\x08\"\x15\n\x13\x65mpty_cache_request\"\x16\n\x14\x65mpty_cache_response\"\x1a\n\x18memory_allocated_request\"5\n\x19memory_allocated_response\x12\x18\n\x10memory_allocated\x18\x01 \x01(\x03\"\x19\n\x17memory_reserved_request\"3\n\x18memory_reserved_response\x12\x17\n\x0fmemory_reserved\x18\x01 \x01(\x03\"U\n\x1dget_device_properties_request\x12\x14\n\ndevice_str\x18\x01 \x01(\tH\x00\x12\x14\n\ndevice_int\x18\x02 \x01(\x05H\x00\x42\x08\n\x06\x64\x65vice\"\xeb\x01\n\x1eget_device_properties_response\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x14\n\x0ctotal_memory\x18\x02 \x01(\x03\x12\x18\n\x10\x61vailable_memory\x18\x03 \x01(\x03\x12\x18\n\x10\x61llocated_memory\x18\x04 \x01(\x03\x12\x17\n\x0freserved_memory\x18\x05 \x01(\x03\x12\x1c\n\x14max_memory_allocated\x18\x06 \x01(\x03\x12\x1b\n\x13max_memory_reserved\x18\x07 \x01(\x03\x12\x1d\n\x15multi_processor_count\x18\x08 \x01(\x05\x32\xfc\x03\n\x0b\x43udaService\x12M\n\x0cis_available\x12\x1d.mytorch.is_available_request\x1a\x1e.mytorch.is_available_response\x12J\n\x0b\x65mpty_cache\x12\x1c.mytorch.empty_cache_request\x1a\x1d.mytorch.empty_cache_response\x12Y\n\x10memory_allocated\x12!.mytorch.memory_allocated_request\x1a\".mytorch.memory_allocated_response\x12V\n\x0fmemory_reserved\x12 .mytorch.memory_reserved_request\x1a!.mytorch.memory_reserved_response\x12h\n\x15get_device_properties\x12&.mytorch.get_device_properties_request\x1a\'.mytorch.get_device_properties_response\x12\x35\n\x0fget_device_name\x12\r.shared.Empty\x1a\x13.shared.StringValueb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.cuda.cuda_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IS_AVAILABLE_REQUEST']._serialized_start=60
  _globals['_IS_AVAILABLE_REQUEST']._serialized_end=82
  _globals['_IS_AVAILABLE_RESPONSE']._serialized_start=84
  _globals['_IS_AVAILABLE_RESPONSE']._serialized_end=129
  _globals['_EMPTY_CACHE_REQUEST']._serialized_start=131
  _globals['_EMPTY_CACHE_REQUEST']._serialized_end=152
  _globals['_EMPTY_CACHE_RESPONSE']._serialized_start=154
  _globals['_EMPTY_CACHE_RESPONSE']._serialized_end=176
  _globals['_MEMORY_ALLOCATED_REQUEST']._serialized_start=178
  _globals['_MEMORY_ALLOCATED_REQUEST']._serialized_end=204
  _globals['_MEMORY_ALLOCATED_RESPONSE']._serialized_start=206
  _globals['_MEMORY_ALLOCATED_RESPONSE']._serialized_end=259
  _globals['_MEMORY_RESERVED_REQUEST']._serialized_start=261
  _globals['_MEMORY_RESERVED_REQUEST']._serialized_end=286
  _globals['_MEMORY_RESERVED_RESPONSE']._serialized_start=288
  _globals['_MEMORY_RESERVED_RESPONSE']._serialized_end=339
  _globals['_GET_DEVICE_PROPERTIES_REQUEST']._serialized_start=341
  _globals['_GET_DEVICE_PROPERTIES_REQUEST']._serialized_end=426
  _globals['_GET_DEVICE_PROPERTIES_RESPONSE']._serialized_start=429
  _globals['_GET_DEVICE_PROPERTIES_RESPONSE']._serialized_end=664
  _globals['_CUDASERVICE']._serialized_start=667
  _globals['_CUDASERVICE']._serialized_end=1175
# @@protoc_insertion_point(module_scope)
