# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorchvision/models/models.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!mytorchvision/models/models.proto\x12\rmytorchvision\x1a\x16shared_msg_types.proto\"!\n\x10WeightEnumString\x12\r\n\x05value\x18\x01 \x01(\t2\xc1\x01\n\rModelsService\x12\x39\n\x08resnet18\x12\x1f.mytorchvision.WeightEnumString\x1a\x0c.shared.UUID\x12\x39\n\x08resnet50\x12\x1f.mytorchvision.WeightEnumString\x1a\x0c.shared.UUID\x12:\n\tresnet152\x12\x1f.mytorchvision.WeightEnumString\x1a\x0c.shared.UUIDb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorchvision.models.models_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_WEIGHTENUMSTRING']._serialized_start=76
  _globals['_WEIGHTENUMSTRING']._serialized_end=109
  _globals['_MODELSSERVICE']._serialized_start=112
  _globals['_MODELSSERVICE']._serialized_end=305
# @@protoc_insertion_point(module_scope)
