# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorchvision/transforms/transforms.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)mytorchvision/transforms/transforms.proto\x12\rmytorchvision\x1a\x16shared_msg_types.proto\"\x1d\n\rGrpcTransform\x12\x0c\n\x04uuid\x18\x01 \x01(\t\"0\n CreateCenterCropTransformRequest\x12\x0c\n\x04size\x18\x01 \x01(\x05\",\n\x1c\x43reateResizeTransformRequest\x12\x0c\n\x04size\x18\x01 \x01(\x05\"<\n\x1f\x43reateNormalizeTransformRequest\x12\x0c\n\x04mean\x18\x01 \x03(\x02\x12\x0b\n\x03std\x18\x02 \x03(\x02\"A\n\x1d\x43reateComposeTransformRequest\x12 \n\x18\x63omponent_transform_uuid\x18\x01 \x03(\t2\xfb\x03\n\x11TransformsService\x12j\n\x19\x43reateCenterCropTransform\x12/.mytorchvision.CreateCenterCropTransformRequest\x1a\x1c.mytorchvision.GrpcTransform\x12\x62\n\x15\x43reateResizeTransform\x12+.mytorchvision.CreateResizeTransformRequest\x1a\x1c.mytorchvision.GrpcTransform\x12\x46\n\x17\x43reateToTensorTransform\x12\r.shared.Empty\x1a\x1c.mytorchvision.GrpcTransform\x12h\n\x18\x43reateNormalizeTransform\x12..mytorchvision.CreateNormalizeTransformRequest\x1a\x1c.mytorchvision.GrpcTransform\x12\x64\n\x16\x43reateComposeTransform\x12,.mytorchvision.CreateComposeTransformRequest\x1a\x1c.mytorchvision.GrpcTransformb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorchvision.transforms.transforms_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GRPCTRANSFORM']._serialized_start=84
  _globals['_GRPCTRANSFORM']._serialized_end=113
  _globals['_CREATECENTERCROPTRANSFORMREQUEST']._serialized_start=115
  _globals['_CREATECENTERCROPTRANSFORMREQUEST']._serialized_end=163
  _globals['_CREATERESIZETRANSFORMREQUEST']._serialized_start=165
  _globals['_CREATERESIZETRANSFORMREQUEST']._serialized_end=209
  _globals['_CREATENORMALIZETRANSFORMREQUEST']._serialized_start=211
  _globals['_CREATENORMALIZETRANSFORMREQUEST']._serialized_end=271
  _globals['_CREATECOMPOSETRANSFORMREQUEST']._serialized_start=273
  _globals['_CREATECOMPOSETRANSFORMREQUEST']._serialized_end=338
  _globals['_TRANSFORMSSERVICE']._serialized_start=341
  _globals['_TRANSFORMSSERVICE']._serialized_end=848
# @@protoc_insertion_point(module_scope)
