# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/scaffolding/scaffolding.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1bmytorch/scaffolding/scaffolding.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"<\n\nClientInfo\x12.\n\x0fkey_value_pairs\x18\x02 \x03(\x0b\x32\x15.mytorch.KeyValuePair2\x8c\x01\n\x0eMyTorchService\x12\x44\n\x1cinitialize_client_connection\x12\x13.mytorch.ClientInfo\x1a\r.shared.Empty\"\x00\x12\x34\n\x0cget_gpu_info\x12\r.shared.Empty\x1a\x13.shared.StringValue\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.scaffolding.scaffolding_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_KEYVALUEPAIR']._serialized_start=64
  _globals['_KEYVALUEPAIR']._serialized_end=106
  _globals['_CLIENTINFO']._serialized_start=108
  _globals['_CLIENTINFO']._serialized_end=168
  _globals['_MYTORCHSERVICE']._serialized_start=171
  _globals['_MYTORCHSERVICE']._serialized_end=311
# @@protoc_insertion_point(module_scope)
