from gRPC_impl import shared_msg_types_pb2 as _shared_msg_types_pb2
from gRPC_impl.mytorch.nn import nn_msg_types_pb2 as _nn_msg_types_pb2
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor
