# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/scaffolding/resource_mgmt.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'mytorch/scaffolding/resource_mgmt.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\"]\n\x0fResourceRequest\x12\x12\n\nauth_token\x18\x01 \x01(\t\x12\x11\n\tclient_ip\x18\x02 \x01(\t\x12\x11\n\tserver_id\x18\x03 \x01(\t\x12\x10\n\x08max_time\x18\x04 \x01(\x05\"\xe4\x01\n\x17ResourceRequestResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x17\n\x0f\x61\x64\x64itional_info\x18\x02 \x01(\t\x12\x13\n\x0bresource_id\x18\x03 \x01(\t\x12\x13\n\x0bresource_ip\x18\x04 \x01(\t\x12\x15\n\rresource_port\x18\x05 \x01(\x05\x12\x15\n\rresource_name\x18\x06 \x01(\t\x12\x12\n\nlease_time\x18\x07 \x01(\x05\x12\x17\n\x0fmytorch_version\x18\x08 \x01(\t\x12\x15\n\rresource_info\x18\t \x01(\t2e\n\x13ResourceMgmtService\x12N\n\x10resource_request\x12\x18.mytorch.ResourceRequest\x1a .mytorch.ResourceRequestResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.scaffolding.resource_mgmt_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RESOURCEREQUEST']._serialized_start=76
  _globals['_RESOURCEREQUEST']._serialized_end=169
  _globals['_RESOURCEREQUESTRESPONSE']._serialized_start=172
  _globals['_RESOURCEREQUESTRESPONSE']._serialized_end=400
  _globals['_RESOURCEMGMTSERVICE']._serialized_start=402
  _globals['_RESOURCEMGMTSERVICE']._serialized_end=503
# @@protoc_insertion_point(module_scope)
