# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/utils/data/data.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dmytorch/utils/data/data.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\"2\n\nGrpcSubset\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61taset_length\x18\x02 \x01(\x05\"J\n\x0eGrpcDataLoader\x12\x0c\n\x04uuid\x18\x01 \x01(\t\x12\x16\n\x0e\x64\x61taset_length\x18\x02 \x01(\x05\x12\x12\n\nbatch_size\x18\x03 \x01(\x05\"\x9e\x01\n\x17\x44\x61taLoaderBatchResponse\x12)\n\rinputs_tensor\x18\x01 \x01(\x0b\x32\x12.shared.GrpcTensor\x12*\n\x0etargets_tensor\x18\x02 \x01(\x0b\x32\x12.shared.GrpcTensor\x12\x15\n\ris_last_batch\x18\x03 \x01(\x08\x12\x15\n\rout_of_bounds\x18\x04 \x01(\x08\"<\n\x13\x43reateSubsetRequest\x12\x14\n\x0c\x64\x61taset_uuid\x18\x01 \x01(\t\x12\x0f\n\x07indices\x18\x02 \x03(\x05\"T\n\x17\x43reateDataLoaderRequest\x12\x14\n\x0c\x64\x61taset_uuid\x18\x01 \x01(\t\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\x12\x0f\n\x07shuffle\x18\x03 \x01(\x08\"C\n\x13GetNextBatchRequest\x12\x17\n\x0f\x64\x61taloader_uuid\x18\x01 \x01(\t\x12\x13\n\x0b\x62\x61tch_index\x18\x02 \x01(\x05\x32\x89\x02\n\x0b\x44\x61taService\x12I\n\x14\x43reateSubsetOnServer\x12\x1c.mytorch.CreateSubsetRequest\x1a\x13.mytorch.GrpcSubset\x12U\n\x18\x43reateDataLoaderOnServer\x12 .mytorch.CreateDataLoaderRequest\x1a\x17.mytorch.GrpcDataLoader\x12X\n\x16GetNextDataLoaderBatch\x12\x1c.mytorch.GetNextBatchRequest\x1a .mytorch.DataLoaderBatchResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.utils.data.data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_GRPCSUBSET']._serialized_start=66
  _globals['_GRPCSUBSET']._serialized_end=116
  _globals['_GRPCDATALOADER']._serialized_start=118
  _globals['_GRPCDATALOADER']._serialized_end=192
  _globals['_DATALOADERBATCHRESPONSE']._serialized_start=195
  _globals['_DATALOADERBATCHRESPONSE']._serialized_end=353
  _globals['_CREATESUBSETREQUEST']._serialized_start=355
  _globals['_CREATESUBSETREQUEST']._serialized_end=415
  _globals['_CREATEDATALOADERREQUEST']._serialized_start=417
  _globals['_CREATEDATALOADERREQUEST']._serialized_end=501
  _globals['_GETNEXTBATCHREQUEST']._serialized_start=503
  _globals['_GETNEXTBATCHREQUEST']._serialized_end=570
  _globals['_DATASERVICE']._serialized_start=573
  _globals['_DATASERVICE']._serialized_end=838
# @@protoc_insertion_point(module_scope)
