# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mytorch/jit/jit.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from gRPC_impl import shared_msg_types_pb2 as shared__msg__types__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15mytorch/jit/jit.proto\x12\x07mytorch\x1a\x16shared_msg_types.proto\"=\n\x12ModelIDandTensorID\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x13\n\x0btensor_uuid\x18\x02 \x01(\t\"/\n\x0bSaveRequest\x12\x12\n\nmodel_uuid\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t2\x98\x01\n\nJitService\x12\x32\n\x05trace\x12\x1b.mytorch.ModelIDandTensorID\x1a\x0c.shared.UUID\x12+\n\x04save\x12\x14.mytorch.SaveRequest\x1a\r.shared.Empty\x12)\n\x04load\x12\x13.shared.StringValue\x1a\x0c.shared.UUIDb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'mytorch.jit.jit_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_MODELIDANDTENSORID']._serialized_start=58
  _globals['_MODELIDANDTENSORID']._serialized_end=119
  _globals['_SAVEREQUEST']._serialized_start=121
  _globals['_SAVEREQUEST']._serialized_end=168
  _globals['_JITSERVICE']._serialized_start=171
  _globals['_JITSERVICE']._serialized_end=323
# @@protoc_insertion_point(module_scope)
